==> haskell-hls-qualify-imported-names-plugin-2.0.0.0-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.0.0.0-HDrf37cwLx99klUktaDaf9

key:
    hls-qualify-imported-names-plugin-2.0.0.0-HDrf37cwLx99klUktaDaf9

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8163172209dc4779fd2b74875c65f65f
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.0.0.0-HDrf37cwLx99klUktaDaf9

depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb ghc-9.4.8
    ghcide-2.0.0.0-AI47rzNyuxX9eV1uxLosjq
    hls-graph-2.0.0.0-4K0C5xFj77kQr7nksdgE9
    hls-plugin-api-2.0.0.0-78u16tmbSwR84BHIUYGjLU
    lsp-1.6.0.0-JFbvvkeeO5R6V24AzOcKk8 text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-qualify-imported-names-plugin-2.0.0.0-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-qualify-imported-names-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-qualify-imported-names-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-qualify-imported-names-plugin-2.0.0.0-7YRoXg5jiFU6r4enAf1xAf

key:
    hls-qualify-imported-names-plugin-2.0.0.0-7YRoXg5jiFU6r4enAf1xAf

license:              Apache-2.0
maintainer:           shenjonathan0@gmail.com
author:               Jonathan Shen
synopsis:
    A Haskell Language Server plugin that qualifies imported names

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  27d0a7e0633cf236ce49149afdff6bf5
exposed:              True
exposed-modules:      Ide.Plugin.QualifyImportedNames
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-qualify-imported-names-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-qualify-imported-names-plugin
hs-libraries:
    HShls-qualify-imported-names-plugin-2.0.0.0-7YRoXg5jiFU6r4enAf1xAf

depends:
    aeson-2.1.2.1-17AWhWkbfJE926UMi0wPlA base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb ghc-9.4.8
    ghcide-2.0.0.0-JT1OJJ4IDapFfwsxE2XHV8
    hls-graph-2.0.0.0-4f2IaKdigsWJX2aDdgRf9T
    hls-plugin-api-2.0.0.0-LqoPpYfIKNtGLq922luErZ
    lsp-1.6.0.0-JFbvvkeeO5R6V24AzOcKk8 text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-2kG5VEC3Gy42AwINT9WJ9w

haddock-interfaces:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html/hls-qualify-imported-names-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-qualify-imported-names-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
